@@ -25,37 +25,37 @@ void insert_diploid_traits(double **offspring, double *paras, int offspr){
     loci_st   = net_st + layers + 3;  /* Col where first loci values start    */
     net_vals  = (loci * traits) + (layers * traits * traits);
     
-    T  = malloc(1 * sizeof(double *));
+    T  = (double **) malloc(1 * sizeof(double *));
     for(row = 0; row < 1; row++){
-        T[row] = malloc(traits * sizeof(double));   
+        T[row] = (double *) malloc(traits * sizeof(double));   
     }
 
-    L  = malloc(1 * sizeof(double *));
+    L  = (double **) malloc(1 * sizeof(double *));
     for(row = 0; row < 1; row++){
-        L[row] = malloc(loci * sizeof(double));   
+        L[row] = (double *) malloc(loci * sizeof(double));   
     }
 
-    loc_layer  = malloc(loci * sizeof(double *));
+    loc_layer  = (double **) malloc(loci * sizeof(double *));
     for(row = 0; row < loci; row++){
-        loc_layer[row] = malloc(traits * sizeof(double));   
+        loc_layer[row] = (double *) malloc(traits * sizeof(double));   
     }
 
-    net   = malloc(layers * sizeof(double *));
+    net   = (double ***) malloc(layers * sizeof(double **));
     for(k = 0; k < layers; k++){
-        net[k] = malloc(traits * sizeof(double *));
+        net[k] = (double **) malloc(traits * sizeof(double *));
         for(i = 0; i < traits; i++){
-            net[k][i] = malloc(traits * sizeof(double));   
+            net[k][i] = (double *) malloc(traits * sizeof(double));   
         }
     }
 
-    net_sum = malloc(traits * sizeof(double *));
+    net_sum = (double **) malloc(traits * sizeof(double *));
     for(row = 0; row < traits; row++){
-        net_sum[row] = malloc(traits * sizeof(double));   
+        net_sum[row] = (double *) malloc(traits * sizeof(double));   
     } 
 
-    loci_to_traits  = malloc(loci * sizeof(double *));
+    loci_to_traits  = (double **) malloc(loci * sizeof(double *));
     for(row = 0; row < loci; row++){
-        loci_to_traits[row] = malloc(traits * sizeof(double));   
+        loci_to_traits[row] = (double *) malloc(traits * sizeof(double));   
     } 
     
     vec_pos = loci_st;
@@ -164,37 +164,37 @@ void insert_haploid_traits(double **offspring, double *paras, int offspr){
     net_st    = trait_st + traits;    /* Column where net locations start     */
     loci_st   = net_st + layers + 2;  /* Col where first loci values start    */
     
-    T  = malloc(1 * sizeof(double *));
+    T  = (double **) malloc(1 * sizeof(double *));
     for(row = 0; row < 1; row++){
-        T[row] = malloc(traits * sizeof(double));   
+        T[row] = (double *) malloc(traits * sizeof(double));   
     }
     
-    L  = malloc(1 * sizeof(double *));
+    L  = (double **) malloc(1 * sizeof(double *));
     for(row = 0; row < 1; row++){
-        L[row] = malloc(loci * sizeof(double));   
+        L[row] = (double *) malloc(loci * sizeof(double));   
     }
     
-    loc_layer  = malloc(loci * sizeof(double *));
+    loc_layer  = (double **) malloc(loci * sizeof(double *));
     for(row = 0; row < loci; row++){
-        loc_layer[row] = malloc(traits * sizeof(double));   
+        loc_layer[row] = (double *) malloc(traits * sizeof(double));   
     }
     
-    net   = malloc(layers * sizeof(double *));
+    net   = (double ***) malloc(layers * sizeof(double **));
     for(k = 0; k < layers; k++){
-        net[k] = malloc(traits * sizeof(double *));
+        net[k] = (double **) malloc(traits * sizeof(double *));
         for(i = 0; i < traits; i++){
-            net[k][i] = malloc(traits * sizeof(double));   
+            net[k][i] = (double *) malloc(traits * sizeof(double));   
         }
     }
     
-    net_sum = malloc(traits * sizeof(double *));
+    net_sum = (double **) malloc(traits * sizeof(double *));
     for(row = 0; row < traits; row++){
-        net_sum[row] = malloc(traits * sizeof(double));   
+        net_sum[row] = (double *) malloc(traits * sizeof(double));   
     } 
     
-    loci_to_traits  = malloc(loci * sizeof(double *));
+    loci_to_traits  = (double **) malloc(loci * sizeof(double *));
     for(row = 0; row < loci; row++){
-        loci_to_traits[row] = malloc(traits * sizeof(double));   
+        loci_to_traits[row] = (double *) malloc(traits * sizeof(double));   
     } 
     
     vec_pos = loci_st;
@@ -883,7 +883,7 @@ void make_offspring(double **pests, double **offspring, double *paras){
     sex_col       = (int) paras[4];
     get_f_coef    = (int) paras[171];
     
-    ind_offspring = malloc(N * sizeof(int));
+    ind_offspring = (int *) malloc(N * sizeof(int));
     for(ind = 0; ind < N; ind++){
         ind_offspring[ind] = (int) pests[ind][offspring_col];
     }
